from betteryeah.generic_response import ChartPlottingResponse
from betteryeah.utils import send_request


class GenericPlugin:

    async def chart_plotting(self, requirements: str, data_desc: str, data: str = None,
                             excel_file: str = None) -> ChartPlottingResponse:
        r"""
        图表插件绘制
        :param requirements:图表绘制要求，包含图表类型（折线、柱状等）、数据维度、工具栏等等图表细节信息
        :param data_desc:数据描述，即针对数据的解释，包含数据含义整体描述、字段含义、数据间逻辑关系等等信息
        :param data:用于生成图表的自定义数据源，可以是任意格式的json数据。
        :param excel_file:excel文件链接，如果用户输入中没有文件链接，默认值为空字符串
        :return 返回markdown格式的字符串
        """
        if data is None and excel_file is None:
            raise Exception("data 与 excel_file 不能同时为空")

        return await ChartPlotting().chart_plotting(requirements, data_desc, data, excel_file)


class ChartPlotting:
    async def chart_plotting(self, requirements: str, data_desc: str, data: str,
                             excel_file: str) -> ChartPlottingResponse:
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {
                    "requirment": requirements,
                    "dataDesc": data_desc,
                    "data": data,
                    "excelFile": excel_file
                },
                "name": "chat"
            }
        }
        return ChartPlottingResponse(await send_request("POST", data))



import os
import json
from typing import List, Optional, Union, AsyncGenerator
from enum import Enum

from betteryeah.generic_client import GenericPlugin
from betteryeah.marketing_client import XiaoHongShuPlugin, ZhihuPlugin, WeiboPlugin, DouyinPlugin, \
    ToutiaoPlugin, BilibiliPlugin
from betteryeah.parse_client import WebParsingClient, ExcelParsingClient, AudioParsingClient, ArticleParsingClient, \
    ArticleParsingModel, VideoParsingClient, AnalysisModeType, OCRFlowClient
from betteryeah.response import LLMResponse, SearchKnowledgeResponse, ExecuteDatabaseResponse, InsertKnowledgeResponse, \
    GenerateImageResponse, VisionImageResponse, SearchResponse, SubFlowResponse, WebParsingResponse, \
    ExcelParsingResponse, AudioParsingResponse, VideoParsingResponse, ExcelOutputType, LLMAvailableModelResponse
from betteryeah.utils import type_check, send_request, send_request_stream


class Model(Enum):
    gpt_3_5_turbo = "gpt-3.5-turbo"
    gpt_3_5_turbo_16k = "gpt-3.5-turbo-16k"
    gpt_4_turbo = "gpt-4-turbo"
    gpt_4o = "gpt-4o"
    chatglm_lite = "chatglm_lite"
    chatglm_lite_32k = "chatglm_lite_32k"
    chatglm_pro = "chatglm_pro"
    chatglm_std = "chatglm_std"
    qwen_turbo = "qwen-turbo"
    qwen_plus = "qwen-plus"
    ERNIE_Bot = "ERNIE-Bot"
    ERNIE_Bot_turbo = "ERNIE-Bot-turbo"
    ERNIE_Bot_4 = "ERNIE-Bot-4"
    Qianfan_Chinese_Llama_2_7B = "Qianfan_Chinese_Llama_2_7B"
    ChatGLM2_6B_32K = "ChatGLM2_6B_32K"
    Llama_2_7b_chat = "Llama-2-7b-chat"
    AquilaChat_7B = "AquilaChat_7B"
    BLOOMZ_7B = "BLOOMZ-7B"
    Llama_2_70b_chat = "Llama-2-70b-chat"
    anthropic_claude_v2 = "anthropic.claude-v2"
    anthropic_claude_instant_v1 = "anthropic.claude-instant-v1"
    anthropic_claude_3_sonnet = "anthropic.claude-3-sonnet"
    anthropic_claude_3_opus = "anthropic.claude-3-opus"
    generalv2 = "generalv2"
    general = "general"
    HuanYuan = "HuanYuan"
    GLM_3_Turbo = "GLM-3-Turbo"
    GLM_4V = "GLM-4V"
    GLM_4 = "GLM-4"
    glm_4_9b = "glm-4-9b"
    gemini = "gemini"
    anthropic_claude_3_haiku = "anthropic.claude-3-haiku"
    gemini_1_5_pro = "Gemini 1.5 Pro"
    moonshot_v1_8k = "moonshot-v1-8k"
    moonshot_v1_32k = "moonshot-v1-32k"
    moonshot_v1_128k = "moonshot-v1-128k"
    skylark2_pro_32k = "skylark2-pro-32k"
    skylark2_pro_turbo_8k = "skylark2-pro-turbo-8k"
    BTY_NeuroText_Enhanced = "BTY-NeuroText-Enhanced"
    claude_3_opus = "claude-3-opus"
    deepseek_chat = "deepseek-chat"
    doubao_pro_128 = "Doubao-pro-128k"
    doubao_pro_32 = "Doubao-pro-32k"
    doubao_pro_4 = "Doubao-pro-4k"


class GenerateImageModel(Enum):
    gpt_4o = "gpt-4o"
    gpt_4_vision_preview = "gpt-4-vision-preview"
    anthropic_claude_3_sonnet = "anthropic.claude-3-sonnet"
    anthropic_claude_3_haiku = "anthropic.claude-3-haiku"
    gemini_1_5_Pro = "Gemini 1.5 Pro"
    gemini_1_5_Flash = "Gemini 1.5 Flash"
    gemini_1_0_Pro_Vision = "Gemini 1.0 Pro Vision"


class MemoryType(Enum):
    INSERT_MEMORY = "insertMemory"
    SEARCH_MEMORY = "searchMemory"


class OutPutType(Enum):
    TEXT = "text"
    JSON = "json"


class HitStrategyType(Enum):
    MIX = 1
    KEY = 2
    SEMANTICS = 3


class SubPluginImage:
    async def vision(self, image_path: List[str], prompt: str = None,
                     model: GenerateImageModel = GenerateImageModel.gpt_4o) -> VisionImageResponse:
        r"""
        AI识图
        :param image_path: 图像的链接地址
        :param prompt: 图像的提示词
        :param model: AI识图使用的模型
        """
        return await VisionImageClient().recognition(image_path=image_path, prompt=prompt, model=model)

    async def generate(self, prompt) -> GenerateImageResponse:
        r"""
        AI生图,如果成功,返回GenerateImageResponse实例的一个对象,这个对象的data属性中包含一个message对象.该对象
        存储生成的图片的url地址
        :param prompt: 图像的提示词
        :return:GenerateImageResponse的一个对象
        """
        return await GenerateImageClient().generate(prompt=prompt)

    async def ocr(self, image_url: str):
        r"""
        使用ocr进行图片识别
        :param image_url: 要识别的图片的url地址数组
        """
        return await OCRFlowClient().parse(image_url)


class SubPluginSearch:
    async def google(self, question: str, parse_web_count: int = 2, domain_name: str = None) -> SearchResponse:
        r"""
        搜索google并返回信息
        :param question: 要搜索的内容
        :param parse_web_count: 解析链接数量,默认为2
        :param domain_name: 指定域名搜索
        :return:SearchResponse的一个对象
        """
        return await GoogleSearchClient().search(question=question, parse_web_count=parse_web_count,
                                                 domain_name=domain_name)

    async def bing(self, question: str, parse_web_count: int = 2, domain_name: str = None) -> SearchResponse:
        r"""
        搜索bing并返回信息
        :param question: 要搜索的内容
        :param parse_web_count: 解析链接数量,默认为2
        :param domain_name: 指定域名搜索
        :return:SearchResponse的一个对象
        """
        return await BingSearchClient().search(question=question, parse_web_count=parse_web_count,
                                               domain_name=domain_name)


class SubPluginParsing:
    async def web(self, url_list: List[str]) -> WebParsingResponse:
        r"""
        :param url_list: 要解析的url地址
        """
        return await WebParsingClient().parse(url_list=url_list)

    async def excel(self, excel_url: str,
                    output_format: ExcelOutputType = ExcelOutputType.HTML) -> ExcelParsingResponse:
        r"""
        :param excel_url: 要解析的excel url地址
        :param output_format: 输出格式
        """
        return await ExcelParsingClient().parse(excel_url=excel_url, output_format=output_format)

    async def audio(self, audio_url: str, auto_split: bool = True) -> AudioParsingResponse:
        r"""
        :param audio_url: 要解析的音频 url地址
        :param auto_split: 是否进行智能分轨,默认为True
        """
        return await AudioParsingClient().parse(audio_url=audio_url, auto_split=auto_split)

    async def video(self, video_url: str,
                    analysis_mode: AnalysisModeType = AnalysisModeType.ScreenshotAndAudio) -> VideoParsingResponse:
        r"""
        解析视频文件,如果AnalysisModeType为OnlyAudio,返回值的data中为字符串,
        如果AnalysisModeType为ScreenshotAndAudio,则返回值data中为List[VideoParsingItem]
        对象
        :param video_url: 解析的视频
        :param analysis_mode: 解析的模式
        """
        return await VideoParsingClient().parse(video_url, analysis_mode)

    async def article(self, long_text_list: List[str], analysis_description: str = "请解析",
                      model: ArticleParsingModel = ArticleParsingModel.Claude) -> AudioParsingResponse:
        r"""
        解析长文本插件
        :param long_text_list: 长文本的文件url地址,该数组的长度最大为2
        :param analysis_description: 解析要求
        :param model: 选择的模型类型
        """
        return await ArticleParsingClient().parse(long_text_list=long_text_list,
                                                  analysis_description=analysis_description,
                                                  model_type=model)


class Plugin:
    image = SubPluginImage()
    search = SubPluginSearch()
    parsing = SubPluginParsing()
    generic = GenericPlugin()
    xiaohongshu = XiaoHongShuPlugin()
    zhihu = ZhihuPlugin()
    weibo = WeiboPlugin()
    douyin = DouyinPlugin()
    toutiao = ToutiaoPlugin()
    bilibili = BilibiliPlugin()


# 客户端基类
class BetterYeah:
    def __init__(self, api_key: str = None, workspace_id: str = None, flow_id: str = "-1", app_id: str = "-1"):
        self.llm = LLMClient()
        self.database = DatabaseClient()
        self.knowledge = KnowledgeClient()
        self.plugin = Plugin()
        self.sub_flow = SubFlowClient()
        if api_key is not None:
            os.environ['API_KEY'] = api_key

        self._config = {}
        if workspace_id is not None:
            self._config["workspace_id"] = workspace_id
        if flow_id is not None:
            self._config["flow_id"] = flow_id
        if flow_id is not None:
            self._config["app_id"] = app_id
        if os.environ.get('RUN_ARGS') is None:
            os.environ['RUN_ARGS'] = json.dumps(self._config)


# 聊天客户端
class LLMClient:

    async def chat(self, system_prompt: str, model: Model | str = Model.gpt_3_5_turbo, json_mode: bool = False,
                   messages: Optional[List[dict]] = None, temperature: float = 0.7,
                   stream: bool = False, time_out=600) -> Union[LLMResponse, AsyncGenerator[str, None]]:
        r"""
        :param system_prompt: 用户输入的prompt
        :param model: 选择的对应模型
        :param json_mode: 输出的文本类型是否是json格式,注意,若为True,请在system_prompt中明确声明返回json的key
        的形式,否则模型会随机返回json的key
        :param messages: 上下文历史信息,例如:[{"role": "user","content": "你好"},{"role": "assistant","content": "你好，有什么可以帮助您？"}]
        :param temperature: 模型对应的temperature参数
        :param stream: 是否使用流式输出
        :param time_out: 请求超时时间
        :return:例如:{'code': 200, 'success': True, 'message': 'SUCCESS', 'data': '汉朝一共有26位皇帝。', 'now_time': 1715395402}
        """
        # 处理 model 参数
        data = {
            "name": "LLM",
            "parameters": {
                "inputs": {
                    "model": model if isinstance(model, str) else model.value,
                    "plugin": {"json_mode": json_mode},
                    "stream": stream,
                    "messages": [] if messages is None else messages,
                    "temperature": temperature,
                    "context_type": "messageList",
                    "system_prompt": system_prompt,
                }
            }
        }
        if stream:
            response = send_request_stream("POST", data, time_out=time_out)

            async def generate() -> AsyncGenerator[str, None]:
                async for chunk in response:
                    yield chunk

            return generate()
        result = await send_request("POST", data, time_out=time_out)

        return LLMResponse(result)

    async def get_available_models(self) -> LLMAvailableModelResponse:
        r"""
        获取当前可用的模型列表
        :return:
        """
        return LLMAvailableModelResponse(await send_request("GET", data={}, endpoint="/oapi/active_channels"))


# 数据库客户端
class DatabaseClient:

    @type_check
    async def execute_database(self, base_id: str, executable_sql: str) -> ExecuteDatabaseResponse:
        r"""
        操作数据库
        :param base_id:数据库的id
        :param executable_sql:执行数据库的对应的sql
        """
        data = {
            "name": "DATABASE",
            "parameters": {
                "inputs": {
                    "baseId": base_id,
                    "executableSQL": executable_sql
                }
            }
        }
        return ExecuteDatabaseResponse(await send_request("POST", data))


# 知识库客户端
class KnowledgeClient:

    @type_check
    async def insert_knowledge(self, content: str, file_id: int, partition_id: int = None) -> InsertKnowledgeResponse:
        r"""
        插入知识库
        :param content: 要插入的知识库的内容
        :param file_id: 插入的知识库id
        :param partition_id: 知识库对应的partition_id
        """
        data = {
            "name": "KNOWLEDGE",
            "parameters": {
                "inputs": {
                    "content": content,
                    "file_id": file_id,
                    "memoryType": MemoryType.INSERT_MEMORY.value,
                    "partition_id": partition_id,
                },
            }
        }
        return InsertKnowledgeResponse(await send_request("POST", data))

    async def search_knowledge(self, search_content: str, partition_id: int, file_ids: Optional[List[int]] = None,
                               tags: Optional[List[str]] = None,
                               output_type: OutPutType = OutPutType.TEXT,
                               hit_strategy: HitStrategyType = HitStrategyType.MIX,
                               max_result_num: int = 3, ranking_strategy: bool = False) -> SearchKnowledgeResponse:
        r"""
        查询知识库
        :param search_content: 查询的内容信息
        :param partition_id: 文件的 partition_id
        :param file_ids: 文件的id列表
        :param tags: 标签名称
        :param output_type: 选择输出类型
        :param hit_strategy: OutPutType中的对象,MIX表示混合查询，KEY表示关键字查询，SEMANTICS表示语义查询
        :param max_result_num: 最大结果数 1-10
        :param ranking_strategy: 指令重排，默认是0,支持指令重排是1
        """
        data = {
            "name": "KNOWLEDGE",
            "parameters": {
                "inputs": {
                    "tags": tags,
                    "memory": partition_id,
                    "file_ids": file_ids,
                    "memoryType": MemoryType.SEARCH_MEMORY.value,
                    "outputType": output_type.value,
                    "hitStrategy": hit_strategy.value,
                    "maxResultNum": max_result_num,
                    "searchContent": search_content,
                    "rankingStrategy": 1 if ranking_strategy else 0
                }
            }
        }
        return SearchKnowledgeResponse(await send_request("POST", data))


class VisionImageClient:

    async def recognition(self, image_path: List[str], prompt: str = None,
                          model: GenerateImageModel = GenerateImageModel.gpt_4o) -> VisionImageResponse:
        r"""
        AI识图
        :param image_path: 图像的链接地址
        :param prompt: 图像的提示词
        :param model: AI识图使用的模型
        """
        if not isinstance(image_path, str):
            tmp_images = []
            [tmp_images.append({"value": i}) for i in image_path]
            image_path = tmp_images
        data = {
            "name": "VISION_IMAGE",
            "parameters": {
                "inputs": {
                    "question": prompt,
                    "image_path": image_path,
                    "model": model.value
                }
            }
        }
        return VisionImageResponse(await send_request("POST", data))


class GenerateImageClient:

    async def generate(self, prompt: str = None) -> GenerateImageResponse:
        r"""
        AI生图,如果成功,返回GenerateImageResponse实例的一个对象,这个对象的data属性中包含一个message对象.该对象
        存储生成的图片的url地址
        :param prompt: 图像的提示词
        :return:GenerateImageResponse的一个对象
        """
        data = {
            "name": "GENERATE_IMAGE",
            "parameters": {
                "inputs": {
                    "prompt": prompt,
                }
            }
        }
        return GenerateImageResponse(await send_request("POST", data))


class GoogleSearchClient:

    async def search(self, question: str, parse_web_count: int = 2, domain_name: str = None) -> SearchResponse:
        r"""
        搜索google并返回信息
        :param question: 要搜索的内容
        :param parse_web_count: 解析链接数量,默认为2
        :param domain_name: 指定域名搜索
        :return:SearchResponse的一个对象
        """
        data = {
            "name": "GOOGLE_SEARCH",
            "parameters": {
                "inputs": {
                    "question": question,
                    "parse_web_count": parse_web_count,
                    "domain_name": domain_name
                }
            }
        }
        return SearchResponse(await send_request("POST", data))


class BingSearchClient:
    async def search(self, question: str, parse_web_count: int = 2, domain_name: str = None) -> SearchResponse:
        r"""
        搜索bing并返回信息
        :param question: 要搜索的内容
        :param parse_web_count: 解析链接数量,默认为2
        :param domain_name: 指定域名搜索
        :return:SearchResponse的一个对象
        """
        data = {
            "name": "BING_SEARCH",
            "parameters": {
                "inputs": {
                    "question": question,
                    "parse_web_count": parse_web_count,
                    "domain_name": domain_name
                }
            }
        }
        return SearchResponse(await send_request("POST", data))


class SubFlowClient:

    async def execute(self, flow_id: str, parameter: dict = None) -> SubFlowResponse:
        r"""
        执行子flow并返回子flow的结果
        :param flow_id: 要执行子flow的id
        :param parameter: 执行的参数
        """
        if parameter is None:
            parameter = {}
        data = {
            "name": "SUB_FLOW",
            "parameters": {
                "inputs": parameter,
                "flow_id": flow_id
            }
        }
        return SubFlowResponse(await send_request("POST", data))



from dataclasses import dataclass
from typing import Optional

from betteryeah.response import BaseResponse


@dataclass
class ChartPlottingResponse(BaseResponse):
    data: Optional[str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data")



from betteryeah.client import (Model, MemoryType, OutPutType, HitStrategyType, BetterYeah, LLMClient,
                               DatabaseClient, KnowledgeClient, LLMResponse, InsertKnowledgeResponse,
                               SearchKnowledgeResponse, ExecuteDatabaseResponse, VisionImageClient,
                               ExcelParsingClient, AudioParsingClient, ArticleParsingClient, SubFlowClient,
                               GenerateImageClient, GoogleSearchClient, BingSearchClient, GenerateImageResponse,
                               VisionImageResponse, SearchResponse, GenerateImageModel, ArticleParsingModel,
                               VideoParsingClient, OCRFlowClient, AnalysisModeType, ExcelOutputType)
from betteryeah.response import (AudioParsingResponse, ExcelParsingResponse, SubFlowResponse, VideoParsingResponse)

from betteryeah.marketing_client import XiaoHongShuCoverSearch, XiaoHongShuCommentSearch, BilibiliRealtimeHotspots, \
    ZhihuRealtimeHotspots, DouyinComments, DouyinVideoAnalysis, XiaoHongShuHotspots, XiaoHongShuHotTopic, \
    XiaoHongShuComment, XiaoHongShuNote, \
    DouyinHotspots, XiaoHongShuNoteSearch, XiaoHongShuTagSearch, XiaoHongShuVogueNoteSearch, \
    XiaoHongShuAccountNoteSearch, \
    ToutiaoHotspots, WeiboHotspots, XiaoHongShuPlugin, DouyinPlugin, ZhihuPlugin, BilibiliPlugin, ToutiaoPlugin, \
    WeiboPlugin

from betteryeah.marketing_response import DouyinHotspotsType
from .version import __version__
__all__ = ["Model", "MemoryType", "OutPutType", "HitStrategyType", "BetterYeah",
           "LLMClient", "DatabaseClient", "KnowledgeClient", "LLMResponse", "InsertKnowledgeResponse",
           "SearchKnowledgeResponse", "ExecuteDatabaseResponse", "VisionImageClient", "GenerateImageClient",
           "ExcelParsingClient", "AudioParsingClient", "ArticleParsingClient", "SubFlowClient",
           "GoogleSearchClient", "BingSearchClient",
           "GenerateImageResponse", "VisionImageResponse", "SearchResponse",
           "AudioParsingResponse", "ExcelParsingResponse", "SubFlowResponse", "GenerateImageModel",
           "ArticleParsingModel", "VideoParsingClient", "VideoParsingResponse",
           "OCRFlowClient", "AnalysisModeType", "XiaoHongShuCoverSearch",
           "XiaoHongShuCommentSearch", "BilibiliRealtimeHotspots", "ZhihuRealtimeHotspots",
           "DouyinComments", "DouyinVideoAnalysis", "XiaoHongShuHotspots", "XiaoHongShuHotTopic",
           "XiaoHongShuComment", "XiaoHongShuNote", "DouyinHotspots", "XiaoHongShuNoteSearch", "XiaoHongShuTagSearch",
           "XiaoHongShuVogueNoteSearch", "XiaoHongShuAccountNoteSearch",
           "ToutiaoHotspots", "WeiboHotspots", "XiaoHongShuPlugin", "DouyinPlugin",
           "ZhihuPlugin", "BilibiliPlugin", "ToutiaoPlugin", "WeiboPlugin", "DouyinHotspotsType", "ExcelOutputType"]



from dataclasses import dataclass, field
from enum import Enum
from typing import Dict, List, Optional

from betteryeah.response import BaseResponse


@dataclass
class XiaoHongShuCoverSearchResponse(BaseResponse):
    data: List[str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data", [])


@dataclass
class XiaoHongShuPopularNotesItem:
    title: str
    url: int
    liked_count: str

    def __init__(self, response_dict: dict):
        self.title = response_dict.get("title")
        self.url = response_dict.get("url")
        self.liked_count = response_dict.get("liked_count")


@dataclass
class XiaoHongShuPopularNotesResponse(BaseResponse):
    data: Optional[list[XiaoHongShuPopularNotesItem]]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            self.data = [XiaoHongShuPopularNotesItem(i) for i in response_dict.get('data')]
        else:
            self.data = None


@dataclass
class XiaoHongShuCommentSearchResponse(BaseResponse):
    data: List[str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data", [])


class BiliBiliHotTopicItem:
    topic: str
    url: str

    def __init__(self, response_dict: dict):
        self.topic = response_dict.get("topic")
        self.url = response_dict.get("url")


@dataclass
class BiliBiliHotTopicResponse(BaseResponse):
    data: List[BiliBiliHotTopicItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [BiliBiliHotTopicItem(i) for i in response_dict.get("data", [])]


@dataclass
class ZhihuRealtimeHotspotsItem:
    topic: str
    url: str
    heat: str
    excerpt: str

    def __init__(self, response_dict: dict):
        self.topic = response_dict.get("topic")
        self.url = response_dict.get("url")
        self.heat = response_dict.get("heat")
        self.excerpt = response_dict.get("excerpt")


@dataclass
class ZhiHuHotTopicResponse(BaseResponse):
    data: List[ZhihuRealtimeHotspotsItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [ZhihuRealtimeHotspotsItem(i) for i in response_dict.get("data", [])]


@dataclass
class DouyinCommentsResponse(BaseResponse):
    data: List[Dict[str, str]]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data", [])


@dataclass
class DouyinVideoAnalysisItemDetail:
    startTime: int
    endTime: int
    text: str
    image: str

    def __init__(self, item: Dict[str, any]):
        self.startTime = item.get("startTime")
        self.endTime = item.get("endTime")
        self.text = item.get("text")
        self.image = item.get("image")


@dataclass
class DouyinVideoAnalysisItem:
    title: Optional[str]
    tags: Optional[List[str]]
    data: Optional[List[DouyinVideoAnalysisItemDetail]]

    def __init__(self, response_dict: dict):
        self.title = response_dict.get("title")
        self.tags = response_dict.get("tags")
        self.data = [DouyinVideoAnalysisItemDetail(item) for item in response_dict.get("data")]


@dataclass
class DouyinVideoAnalysisResponse(BaseResponse):
    data: Optional[DouyinVideoAnalysisItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            self.data = DouyinVideoAnalysisItem(response_dict.get("data"))
        else:
            self.data = None


@dataclass
class WeiboHotspotItem:
    title: str
    heat: int
    category: str

    def __init__(self, hotspot: Dict[str, any]):
        self.title = hotspot.get("topic")
        self.heat = hotspot.get("heat")
        self.category = hotspot.get("category")


@dataclass
class WeiboHotspotsResponse(BaseResponse):
    data: List[WeiboHotspotItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [WeiboHotspotItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuHotspotItem:
    topic: str
    heat: str
    relatedHottestNote: Dict[str, any]

    def __init__(self, hotspot: Dict[str, any]):
        self.topic = hotspot.get("topic")
        self.heat = hotspot.get("heat")
        self.relatedHottestNote = {
            "title": hotspot["relatedHottestNote"].get("title"),
            "mainBody": hotspot["relatedHottestNote"].get("mainBody"),
            "tags": hotspot["relatedHottestNote"].get("tags"),
            "comments": hotspot["relatedHottestNote"].get("comments")
        }


@dataclass
class XiaoHongShuHotTopicResponse(BaseResponse):
    data: List[XiaoHongShuHotspotItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuHotspotItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuHotTopicResponse(BaseResponse):
    data: List[str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data", [])


@dataclass
class XiaoHongShuCommentItem:
    content: str
    create_time: str
    like_count: int
    sub_comments: List['XiaoHongShuCommentItem'] = field(default_factory=list)

    def __init__(self, comment: Dict[str, any]):
        self.content = comment.get("content")
        self.create_time = comment.get("create_time")
        self.like_count = comment.get("like_count")
        self.sub_comments = [XiaoHongShuCommentItem(sub) for sub in comment.get("sub_comments", [])]


@dataclass
class XiaoHongShuCommentResponse(BaseResponse):
    data: List[XiaoHongShuCommentItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuCommentItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuNoteDetailItem:
    title: str
    desc: str
    url: str
    id: str
    image: str
    imageList: List[str]
    likes: int
    comments: int
    collects: int
    shareCount: int
    tags: List[str]

    def __init__(self, note_details: Dict[str, any]):
        self.title = note_details.get("title")
        self.desc = note_details.get("desc")
        self.url = note_details.get("url")
        self.id = note_details.get("id")
        self.image = note_details.get("image")
        self.imageList = note_details.get("imageList", [])
        self.likes = note_details.get("likes", 0)
        self.comments = note_details.get("comments", 0)
        self.collects = note_details.get("collects", 0)
        self.shareCount = note_details.get("shareCount", 0)
        self.tags = note_details.get("tags", [])


@dataclass
class XiaoHongShuNoteDetailResponse(BaseResponse):
    data: XiaoHongShuNoteDetailItem

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data"):
            self.data = XiaoHongShuNoteDetailItem(response_dict["data"])
        else:
            self.data = XiaoHongShuNoteDetailItem({})


class DouyinHotspotsType(Enum):
    hot = "热榜"
    entertainment = "娱乐榜"
    society = "社会榜"
    challenge = "挑战榜"


@dataclass
class DouyinHotspotItem:
    topic: str
    url: str
    heat: int

    def __init__(self, hotspot: Dict[str, any]):
        self.topic = hotspot.get("topic")
        self.url = hotspot.get("url")
        self.heat = hotspot.get("heat")


@dataclass
class DouYinHotTopicResponse(BaseResponse):
    data: List[DouyinHotspotItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [DouyinHotspotItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuNoteItem:
    url: str
    liked_count: int
    author_name: str
    author_id: str
    fan_count: int
    liked_fan_rate: float

    def __init__(self, note_details: Dict[str, any]):
        self.url = note_details.get("url")
        self.liked_count = note_details.get("liked_count")
        self.author_name = note_details.get("author_name")
        self.author_id = note_details.get("author_id")
        self.fan_count = note_details.get("fan_count")
        self.liked_fan_rate = note_details.get("liked_fan_rate")


@dataclass
class XiaoHongShuNoteSearchResponse(BaseResponse):
    data: List[XiaoHongShuNoteItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuNoteItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuSearchNotesItem:
    id: str
    title: str
    url: str
    likedCount: str

    def __init__(self, item_dict):
        self.id = item_dict.get("id")
        self.title = item_dict.get("title")
        self.url = item_dict.get("url")
        self.likedCount = item_dict.get("likedCount")


@dataclass
class XiaoHongShuSearchNotesResponse(BaseResponse):
    data: Optional[List[XiaoHongShuSearchNotesItem]]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data", []) is not None:
            self.data = [XiaoHongShuSearchNotesItem(item) for item in response_dict.get("data", []).get("list", [])]


@dataclass
class XiaoHongShuTagItem:
    tag: str
    usageFrequency: int

    def __init__(self, tag_info: Dict[str, any]):
        self.tag = tag_info.get("tag")
        self.usageFrequency = tag_info.get("usageFrequency")


@dataclass
class XiaoHongShuSearchTagResponse(BaseResponse):
    data: List[XiaoHongShuTagItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuTagItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuVogueNoteItem:
    title: str
    url: str
    liked_count: int

    def __init__(self, note_details: Dict[str, any]):
        self.title = note_details.get("title")
        self.url = note_details.get("url")
        self.liked_count = note_details.get("liked_count")


@dataclass
class XiaoHongShuVogueNoteSearchResponse(BaseResponse):
    data: List[XiaoHongShuVogueNoteItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuVogueNoteItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuPopularNotesSearchItem:
    url: str
    title: str
    liked_count: int
    author_name: str
    author_id: str
    fan_count: int
    liked_fan_rate: float

    def __init__(self, note_details: Dict[str, any]):
        self.url = note_details.get("url")
        self.title = note_details.get("title")
        self.liked_count = note_details.get("liked_count")
        self.author_name = note_details.get("author_name")
        self.author_id = note_details.get("author_id")
        self.fan_count = note_details.get("fan_count")
        self.liked_fan_rate = note_details.get("liked_fan_rate")


@dataclass
class XiaoHongShuPopularNotesResponse(BaseResponse):
    data: List[XiaoHongShuPopularNotesSearchItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuPopularNotesSearchItem(item) for item in response_dict.get("data", [])]


@dataclass
class XiaoHongShuAccountNoteItem:
    title: str
    url: str
    liked_count: int

    def __init__(self, note_details: Dict[str, any]):
        self.title = note_details.get("title")
        self.url = note_details.get("url")
        self.liked_count = note_details.get("liked_count")


@dataclass
class XiaoHongShuAccountNoteSearchResponse(BaseResponse):
    data: List[XiaoHongShuAccountNoteItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [XiaoHongShuAccountNoteItem(item) for item in response_dict.get("data", [])]


@dataclass
class ToutiaoHotspotItem:
    title: str
    url: str
    heat: int

    def __init__(self, hotspot: Dict[str, any]):
        self.title = hotspot.get("topic")
        self.url = hotspot.get("url")
        self.heat = hotspot.get("heat")


@dataclass
class ToutiaoTouTiaoHotTopicResponse(BaseResponse):
    data: List[ToutiaoHotspotItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [ToutiaoHotspotItem(item) for item in response_dict.get("data", [])]


@dataclass
class WeiboHotspotItem:
    topic: str
    heat: int
    category: str

    def __init__(self, response_dict: dict):
        self.topic = response_dict.get("topic")
        self.heat = response_dict.get("heat")
        self.category = response_dict.get("category")


@dataclass
class WeiboHotspotsResponse(BaseResponse):
    data: Optional[List[WeiboHotspotItem]]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [WeiboHotspotItem(item) for item in response_dict.get('data', [])]



import inspect
import json
import os
import aiohttp
from functools import wraps
from typing import get_origin, get_args, Union, AsyncGenerator

base_url = "https://api.betterai.com/v1" if os.environ.get("GEMINI_SERVER_HOST") is None else os.getenv(
    "GEMINI_SERVER_HOST") + "/v1"


async def get_workspace_id():
    if os.environ.get("RUN_ARGS"):
        try:
            run_args = json.loads(os.environ.get("RUN_ARGS"))
            if run_args.get("workspace_id"):
                os.environ["workspace_id"] = run_args.get("workspace_id")
                return
        except Exception as e:
            pass
    if not os.getenv('API_KEY'):
        raise Exception(f"请设置api_key")
    endpoint = "/oapi/integration/get_workspace_id"
    async with aiohttp.ClientSession() as session:
        async with session.request("POST", f"{base_url}{endpoint}",
                                   json={"Authorization": f"{os.getenv('API_KEY')}"}) as response:
            result = await response.json()
            if result.get("code") == 200 and result.get("data"):
                os.environ["workspace_id"] = result.get("data").get("workspace_id")
            else:
                raise Exception(f"获取workspace_id失败,返回的结果:{result},请确认apikey是否正确")


async def request_build_base(data: dict, endpoint: str = "/integration"):
    if data.get("run_args") is None and os.getenv("RUN_ARGS"):
        data["run_args"] = os.getenv("RUN_ARGS")

    if not os.environ.get("workspace_id"):
        await get_workspace_id()
    headers = {
        "Authorization": f"{os.getenv('API_KEY')}",
        "Content-Type": "application/json",
        "Workspace-Id": os.environ.get("workspace_id")
    }

    url = f"{base_url}{endpoint}"
    return url, headers


async def send_request(method: str, data: dict, endpoint: str = "/oapi/integration", time_out=600) -> dict:
    timeout = aiohttp.ClientTimeout(total=time_out, sock_read=None)  # 禁用读取超时
    url, headers = await request_build_base(data, endpoint)
    async with aiohttp.ClientSession(timeout=timeout) as session:
        async with session.request(method, url, json=data, headers=headers) as response:
            return await response.json()


async def send_request_stream(method: str, data: dict, endpoint: str = "/oapi/integration",
                              time_out=600) -> AsyncGenerator:
    timeout = aiohttp.ClientTimeout(total=time_out, sock_read=None)  # 禁用读取超时
    url, headers = await request_build_base(data, endpoint)
    async with aiohttp.ClientSession(timeout=timeout) as session:
        async with session.request(method, url, json=data, headers=headers) as response:
            # 根据需要处理流式传输
            async for res in response.content:
                decoded_line = res.decode('utf-8').strip()
                if decoded_line.startswith("data:"):
                    data_content = decoded_line[5:].strip()
                    yield data_content


async def abcd(check: bool) -> Union[
    dict | AsyncGenerator]:
    if check:
        async def generator():
            yield 123

        return generator()
    else:
        return {}


def type_check(func):
    @wraps(func)
    def wrapper(*args, **kwargs):
        annotations = func.__annotations__
        all_args = inspect.getcallargs(func, *args, **kwargs)

        def check_type(val, exp_type):
            if val is None:
                # 如果值是None，只有在类型是Optional时才是合法的
                return get_origin(exp_type) is Union and type(None) in get_args(exp_type)
            origin = get_origin(exp_type)
            if origin is Union:
                # 如果类型是Union，检查是否至少有一个类型匹配
                return any(check_type(val, t) for t in get_args(exp_type))
            elif origin:
                # 处理其他泛型类型，如List或Dict
                if not isinstance(val, origin):
                    raise TypeError(
                        f"调用{func.__name__}方法的参数{arg}类型不正确,要求传入的类型为{origin.__name__},实际传入的类型为{type(val).__name__}")
                args_type = get_args(exp_type)
                if args_type and not all(check_type(item, args_type[0]) for item in val):
                    return False
                return True
            else:
                # 非泛型类型检查
                if not isinstance(val, exp_type):
                    raise TypeError(
                        f"调用{func.__name__}方法的参数{arg}类型不正确,要求传入的类型为{exp_type.__name__},实际传入的类型为{type(val).__name__}")
                return True

        for arg, value in all_args.items():
            expected_type = annotations.get(arg)
            if expected_type is None:
                continue  # 如果没有类型注解则跳过

            # 进行类型检查
            if not check_type(value, expected_type):
                raise TypeError(f"调用{func.__name__}方法的参数{arg}不符合类型要求。")

        return func(*args, **kwargs)

    return wrapper



from enum import Enum
from typing import List

from betteryeah.response import WebParsingResponse, ExcelParsingResponse, AudioParsingResponse, VideoParsingResponse, \
    OCRParsingResponse, ExcelOutputType
from betteryeah.utils import type_check, send_request


class WebParsingClient:

    async def parse(self, url_list: List[str]) -> WebParsingResponse:
        r"""
        :param url_list: 要解析的url地址数组
        """
        if len(url_list) < 1:
            return WebParsingResponse({'code': 200, 'success': True, 'message': 'SUCCESS', 'data': []})
        # 处理 model 参数
        data = {
            "name": "WEB_PARSING",
            "parameters": {
                "inputs": {
                    "url": ",".join(url_list),
                }
            }
        }
        return WebParsingResponse(await send_request("POST", data))


class ExcelParsingClient:

    @type_check
    async def parse(self, excel_url: str,
                    output_format: ExcelOutputType = ExcelOutputType.JSON) -> ExcelParsingResponse:
        r"""
        :param excel_url: 要解析的excel url地址
        :param output_format: 输出格式
        """
        # 处理 model 参数
        data = {
            "name": "EXCEL_PARSING",
            "parameters": {
                "inputs": {
                    "excel_url": excel_url,
                    "output_format": output_format.value
                }
            }
        }
        return ExcelParsingResponse(await send_request("POST", data))


class AudioParsingClient:

    @type_check
    async def parse(self, audio_url: str, auto_split: bool = True) -> AudioParsingResponse:
        r"""
        :param audio_url: 要解析的音频 url地址
        :param auto_split: 是否进行智能分轨,默认为True
        """
        # 处理 model 参数
        data = {
            "name": "AUDIO_PARSING",
            "parameters": {
                "inputs": {
                    "audio_url": audio_url,
                    "auto_split": auto_split
                }
            }
        }
        return AudioParsingResponse(await send_request("POST", data))


class ArticleParsingModel(Enum):
    Kimi = "Kimi"
    Claude = "Claude"


class ArticleParsingClient:

    async def parse(self, long_text_list: List[str], analysis_description: str = "请解析",
                    model_type: ArticleParsingModel = ArticleParsingModel.Claude) -> AudioParsingResponse:
        r"""
        :param long_text_list: 长文本的文件url地址,该数组的长度最大为2
        :param analysis_description: 解析要求
        :param model_type: 选择的模型类型
        """
        data = {
            "name": "ARTICLE_PARSING",
            "parameters": {
                "inputs": {
                    "long_text_list": [{"value": item} for item in long_text_list],
                    "analysis_description": analysis_description,
                    "model_type": model_type.value
                }
            }
        }
        return AudioParsingResponse(await send_request("POST", data))


class AnalysisModeType(Enum):
    ScreenshotAndAudio = 0
    OnlyAudio = 1


class VideoParsingClient:
    async def parse(self, video_url: str,
                    analysis_mode: AnalysisModeType = AnalysisModeType.ScreenshotAndAudio) -> VideoParsingResponse:
        r"""
        :param analysis_mode: 长文本的文件url地址,该数组的长度最大为2
        :param video_url: 解析要求
        :param analysis_mode: 选择的模型类型
        """
        data = {
            "name": "VIDEO_PARSING",
            "parameters": {
                "inputs": {
                    "video_url": video_url,
                    "analysis_mode": analysis_mode.value
                }
            }
        }
        return VideoParsingResponse(await send_request("POST", data))


class OCRFlowClient:
    async def parse(self, image_url: str) -> OCRParsingResponse:
        r"""
        OCR识图
        :param image_url: 要解析的ocr url地址数组
        """
        data = {
            "name": "OCR_PARSING",
            "parameters": {
                "inputs": {
                    "image_url": image_url
                }
            }
        }
        return OCRParsingResponse(await send_request("POST", data))



import json
from dataclasses import dataclass, field
from typing import List, Optional, Dict, Any
from enum import Enum


@dataclass
class BaseResponse:
    code: int
    message: str
    now_time: int
    success: str
    usage: dict

    def __init__(self, response_dict: dict):
        self.set_base_result(response_dict)

    def set_base_result(self, response_dict: dict):
        self.code = response_dict.get("code")
        self.message = response_dict.get("message")
        self.success = response_dict.get("success")
        self.now_time = response_dict.get("now_time")
        if isinstance(response_dict.get("data"), dict) and response_dict.get("data").get("upgrade_consume") is not None:
            upgrade_consume = response_dict.get("data").get("upgrade_consume")
        else:
            upgrade_consume = 0
        self.usage = response_dict.get("usage", {'consume': upgrade_consume})


@dataclass
class LLMResponse(BaseResponse):
    data: [str | dict]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data")


@dataclass
class LLMAvailableModelItem:
    name: str
    model: str
    llm_consume_points: int

    def __init__(self, response_dict: dict):
        self.name = response_dict.get("name")
        self.model = response_dict.get("model")
        self.llm_consume_points = response_dict.get("llm_consume_points")


@dataclass
class LLMAvailableModelResponse(BaseResponse):
    data: List[LLMAvailableModelItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = [LLMAvailableModelItem(i) for i in response_dict.get("data", [])]


class FileType(Enum):
    FILE = 1
    TEXT = 2
    WEBPAGE = 3
    TEMPLATE_FILE = 4
    QA = 5


class HitStrategyType(Enum):
    MIX = 1
    KEY = 2
    SEMANTICS = 3


@dataclass
class InsertKnowledgeItem:
    file_id: [int]
    partition_id: int

    def __init__(self, response_dict: dict):
        self.partition_id = response_dict.get("partition_id")
        self.file_id = response_dict.get("file_id")


@dataclass
class InsertKnowledgeResponse(BaseResponse):
    data: Optional[InsertKnowledgeItem]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            self.data = InsertKnowledgeItem(response_dict)
        else:
            self.data = None


@dataclass
class WebParsingItem:
    url: str
    content: str

    def __init__(self, response_dict: dict):
        self.url = response_dict.get("url")
        self.content = response_dict.get("content")


@dataclass
class WebParsingResponse(BaseResponse):
    data: Optional[List[WebParsingItem]]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            self.data = [WebParsingItem(i) for i in response_dict.get("data")]
        else:
            self.data = None


@dataclass
class KnowledgeMatchContent:
    vector_id: str
    file_id: int
    file_type: FileType
    file_name: str
    mimetype: Optional[str]
    chunk_id: int
    content: str
    keywords: List[str]
    extra_info: Dict[str, str]
    matched_keywords: List[str]
    relevance_score: Dict[str, Optional[float]]

    def __init__(self, response_dict: dict):
        self.vector_id = response_dict.get("vector_id")
        self.file_id = response_dict.get("file_id")
        self.file_type = response_dict.get("file_type")
        self.file_name = response_dict.get("file_name")
        self.mimetype = response_dict.get("mimetype")
        self.chunk_id = response_dict.get("chunk_id")
        self.content = response_dict.get("content")
        self.keywords = response_dict.get("keywords")
        self.extra_info = response_dict.get("extra_info")
        self.matched_keywords = response_dict.get("matched_keywords")
        self.relevance_score = response_dict.get("relevance_score")

    @staticmethod
    def from_json(json_str: str):
        data = json.loads(json_str)
        return KnowledgeMatchContent(data)


@dataclass
class SearchKnowledgeItem:
    cost_time: float
    match_contents: List[KnowledgeMatchContent]
    usage: Any
    synonym_note: Any

    def __init__(self, cost_time: float, match_contents: List[KnowledgeMatchContent], usage: Any,
                 synonym_note: Any):
        self.cost_time = cost_time
        self.match_contents = match_contents
        self.usage = usage
        self.synonym_note = synonym_note

    @staticmethod
    def from_json(response_dict: dict):
        match_contents = [KnowledgeMatchContent.from_json(json.dumps(mc)) for mc in
                          response_dict['data']['match_contents']]
        result_data = {
            'cost_time': response_dict['data']['cost_time'],
            'match_contents': match_contents,
            'usage': response_dict['data']['usage'],
            'synonym_note': response_dict['data']['synonym_note'],
        }
        return SearchKnowledgeItem(**result_data)


@dataclass
class SearchKnowledgeResponse(BaseResponse):
    data: [SearchKnowledgeItem | str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("success"):
            if isinstance(response_dict.get("data"), str):
                self.data = response_dict.get("data")
            else:
                self.data = SearchKnowledgeItem.from_json(response_dict)
        else:
            self.data = None


@dataclass
class ExecuteDatabaseResponse(BaseResponse):
    command: str
    rowCount: int
    data: any

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.command = response_dict.get("command")
        self.rowCount = response_dict.get("rowCount")
        self.data = response_dict.get("data")


@dataclass
class GenerateImageResponse(BaseResponse):
    data: str

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data")


@dataclass
class VisionImageResponse(BaseResponse):
    data: str

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data")


@dataclass
class SearchItem:
    title: str
    url: str
    content: str
    snippet: str

    def __init__(self, response_dict: dict):
        self.title = response_dict.get("title")
        self.url = response_dict.get("url")
        self.content = response_dict.get("content")
        self.snippet = response_dict.get("snippet")


@dataclass
class SearchResponse(BaseResponse):
    data: Optional[List[SearchItem]] | str

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            if isinstance(response_dict.get("data"), str):
                self.data = response_dict.get("data")
                return
            self.data = [SearchItem(i) for i in response_dict.get("data")]


class ExcelOutputType(Enum):
    HTML = 1
    JSON = 2


@dataclass
class ExcelParsingResponse(BaseResponse):
    data: Any

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data")


@dataclass
class AudioParsingResponse(BaseResponse):
    data: Optional[str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = response_dict.get("data")


@dataclass
class SubFlowExecuteOutput:
    # 流程id
    flow_id: str
    # 执行任务id
    task_id: str
    # 执行结果
    run_result: str
    # 执行时长
    durationTime: Any
    # 执行信息
    message: str

    status: str

    def __init__(self, response_dict: dict):
        if response_dict is not None:
            self.flow_id = response_dict.get("flow_id")
            self.task_id = response_dict.get("task_id")
            self.run_result = response_dict.get("run_result")
            self.durationTime = response_dict.get("durationTime")
            self.message = response_dict.get("message")
            self.status = response_dict.get("status")
        else:
            self.flow_id = ""
            self.task_id = ""
            self.run_result = ""
            self.durationTime = ""
            self.message = ""
            self.status = ""


@dataclass
class SubFlowResponse(BaseResponse):
    data: Optional[SubFlowExecuteOutput]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        self.data = SubFlowExecuteOutput(response_dict.get("data"))


@dataclass
class VideoParsingItem:
    begin_time: int
    end_time: int
    silence_duration: int
    speaker_id: str
    text: str
    channel_id: int
    speech_rate: int
    emotion_value: float
    image: str = None

    def __init__(self, response_dict: dict):
        self.begin_time = response_dict.get("BeginTime")
        self.end_time = response_dict.get("EndTime")
        self.silence_duration = response_dict.get("SilenceDuration")
        self.speaker_id = response_dict.get("SpeakerId")
        self.text = response_dict.get("Text")
        self.channel_id = response_dict.get("ChannelId")
        self.speech_rate = response_dict.get("SpeechRate")
        self.emotion_value = response_dict.get("EmotionValue")
        self.image = response_dict.get("image")


@dataclass
class VideoParsingResponse(BaseResponse):
    data: Optional[List[VideoParsingItem] | str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            if isinstance(response_dict.get("data"), str):
                self.data = response_dict.get("data")
            elif isinstance(response_dict.get("data"), list):
                self.data = [VideoParsingItem(i) for i in response_dict.get("data")]
            else:
                self.data = None
        else:
            self.data = None


@dataclass
class OCRParsingResponse(BaseResponse):
    data: Optional[str]

    def __init__(self, response_dict: dict):
        super().__init__(response_dict)
        if response_dict.get("data") is not None:
            self.data = response_dict.get("data")
        else:
            self.data = None



from typing import List

from betteryeah.marketing_response import XiaoHongShuCoverSearchResponse, XiaoHongShuCommentSearchResponse, \
    BiliBiliHotTopicResponse, ZhiHuHotTopicResponse, DouyinCommentsResponse, \
    DouyinVideoAnalysisResponse, XiaoHongShuHotTopicResponse, XiaoHongShuCommentResponse, \
    DouYinHotTopicResponse, XiaoHongShuSearchTagResponse, XiaoHongShuVogueNoteSearchResponse, \
    XiaoHongShuAccountNoteSearchResponse, ToutiaoTouTiaoHotTopicResponse, \
    WeiboHotspotsResponse, DouyinHotspotsType, XiaoHongShuNoteDetailResponse, XiaoHongShuSearchNotesResponse, \
    XiaoHongShuPopularNotesResponse
from betteryeah.utils import send_request


class XiaoHongShuCoverSearch:
    async def search_covers(self, urls: List[str]) -> XiaoHongShuCoverSearchResponse:
        r"""
        小红书笔记封面批量查询
        :param urls: 笔记链接列表
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"urls": urls},
                "name": "xhs_cover_search"
            }
        }
        return XiaoHongShuCoverSearchResponse(await send_request("POST", data))


class XiaoHongShuCommentSearch:
    async def search_comments(self, urls: List[str], count: int) -> XiaoHongShuCommentSearchResponse:
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"urls": urls, "count": count},
                "name": "xhs_comment_search"
            }
        }
        return XiaoHongShuCommentSearchResponse(await send_request("POST", data))


class BilibiliRealtimeHotspots:
    async def get_hotspots(self) -> BiliBiliHotTopicResponse:
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {},
                "name": "bilibili_realtime_hotspots"
            }
        }
        return BiliBiliHotTopicResponse(await send_request("POST", data))


class ZhihuRealtimeHotspots:
    async def get_hotspots(self) -> ZhiHuHotTopicResponse:
        """
        获取知乎实时热搜榜
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {},
                "name": "zhihu_realtime_hotspots"
            }
        }
        return ZhiHuHotTopicResponse(await send_request("POST", data))


class DouyinComments:
    async def get_comments(self, url: str) -> DouyinCommentsResponse:
        """
        通过抖音链接，获取相关评论
        :param url: 抖音视频的URL地址
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"url": url},
                "name": "douyin_comment"
            }
        }
        return DouyinCommentsResponse(await send_request("POST", data))


class DouyinVideoAnalysis:
    async def analyze_video(self, url: str) -> DouyinVideoAnalysisResponse:
        """
        通过抖音链接，获取视频文案和相关截图
        :param url: 抖音视频的URL地址
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"url": url},
                "name": "douyin_video"
            }
        }
        return DouyinVideoAnalysisResponse(await send_request("POST", data))


class XiaoHongShuHotspots:
    async def get_hotspots(self) -> XiaoHongShuHotTopicResponse:
        """
        获取小红书实时热点及相关热贴和评论
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {},
                "name": "xhs_hotspots"
            }
        }
        return XiaoHongShuHotTopicResponse(await send_request("POST", data))


class XiaoHongShuHotTopic:
    async def get_hot_topic_comments(self, keyword: str) -> XiaoHongShuHotTopicResponse:
        """
        评论洞察
        搜索关键词，得到多篇热门笔记的热评
        :param keyword: 搜索关键字
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"keyword": keyword},
                "name": "xhs_hot_topic"
            }
        }
        return XiaoHongShuHotTopicResponse(await send_request("POST", data))


class XiaoHongShuComment:
    async def get_comments(self, url: str) -> XiaoHongShuCommentResponse:
        """
        通过小红书链接，获取笔记评论数据
        :param url: 笔记的URL地址
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"url": url},
                "name": "xhs_comment"
            }
        }
        return XiaoHongShuCommentResponse(await send_request("POST", data))


class XiaoHongShuNote:
    async def get_note_details(self, url: str) -> XiaoHongShuNoteDetailResponse:
        """
        通过小红书笔记链接，获取标题、正文、封面图、轮播图、视频、点赞量、评论量、收藏量、分享量、标签信息
        :param url: 笔记的URL地址
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"url": url},
                "name": "xhs_note"
            }
        }
        return XiaoHongShuNoteDetailResponse(await send_request("POST", data))


class DouyinHotspots:
    async def get_hotspots(self, type: DouyinHotspotsType) -> DouYinHotTopicResponse:
        """
        获取抖音实时热搜榜
        :param type: 榜单类型（如“热榜”、“娱乐榜”等）
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"type": type.value},
                "name": "douyin_realtime_hotspots"
            }
        }
        return DouYinHotTopicResponse(await send_request("POST", data))


class XiaoHongShuNoteSearch:
    async def search_notes(self, question: str) -> XiaoHongShuSearchNotesResponse:
        """
        根据关键词搜索笔记，返回指定数量的笔记详情
        :param keyword: 搜索的问题
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"question": question},
                "name": "xhs_search"
            }
        }
        return XiaoHongShuSearchNotesResponse(await send_request("POST", data))


class XiaoHongShuTagSearch:
    async def search_tags(self, keyword: str) -> XiaoHongShuSearchTagResponse:
        """
        根据关键词搜索，返回最热100篇笔记的标签及其使用频率
        :param keyword: 搜索的关键词
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"keyword": keyword},
                "name": "xhs_tag"
            }
        }
        return XiaoHongShuSearchTagResponse(await send_request("POST", data))


class XiaoHongShuVogueNoteSearch:
    async def search_vogue_notes(self, keyword: str, count: int) -> XiaoHongShuVogueNoteSearchResponse:
        """
        根据搜索关键词获取小红书上的爆款（最热门）笔记，可以配置要获取的笔记数目
        :param keyword: 搜索的关键词
        :param count: 要获取的笔记数量，默认为10篇
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"keyword": keyword, "count": count},
                "name": "xhs_vogue_note"
            }
        }
        return XiaoHongShuVogueNoteSearchResponse(await send_request("POST", data))


class XiaoHongShuPopularNotesWithLowFollowerSearch:
    async def search_low_follower_hits(self, keyword: str, count: int) -> XiaoHongShuPopularNotesResponse:
        """
        搜索关键词，获取小红书上的低粉爆款笔记（低粉丝量的作者发布的爆款笔记），可以指定要获取的笔记数量，默认返回10篇
        :param keyword: 搜索的关键词
        :param count: 要获取的笔记数量
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"keyword": keyword, "count": count},
                "name": "xhs_popular_notes_low_followers"
            }
        }
        return XiaoHongShuPopularNotesResponse(await send_request("POST", data))


class XiaoHongShuAccountNoteSearch:
    async def search_account_notes(self, author_id: str, count: int) -> XiaoHongShuAccountNoteSearchResponse:
        """
        根据小红书账号ID查询该账号下最热门笔记，可以指定要获取的笔记数量
        :param author_id: 小红书账号ID
        :param count: 要获取的笔记数量
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {"authorId": author_id, "count": count},
                "name": "xhs_account_note"
            }
        }
        return XiaoHongShuAccountNoteSearchResponse(await send_request("POST", data))


class ToutiaoHotspots:
    async def get_hotspots(self) -> ToutiaoTouTiaoHotTopicResponse:
        """
        获取今日头条实时热搜榜
        """
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {},
                "name": "toutiao_realtime_hotspots"
            }
        }
        return ToutiaoTouTiaoHotTopicResponse(await send_request("POST", data))


class WeiboHotspots:
    async def fetch_hotspots(self) -> WeiboHotspotsResponse:
        """
        获取微博实时热搜榜单
        """
        # 处理 model 参数
        data = {
            "name": "EXECUTE_FLOW_PLUGIN",
            "parameters": {
                "inputs": {},
                "name": "weibo_hotspots"
            }
        }
        return WeiboHotspotsResponse(await send_request("POST", data))


class XiaoHongShuPlugin:

    async def search_covers(self, urls: List[str]) -> XiaoHongShuCoverSearchResponse:
        r"""
        小红书笔记封面批量查询
        :param urls: 笔记链接列表
        """
        return await XiaoHongShuCoverSearch().search_covers(urls=urls)

    async def search_comments(self, urls: List[str], count: int) -> XiaoHongShuCommentSearchResponse:
        r"""
        小红书评论批量查询
        :param urls: 笔记链接列表
        :param count: 返回的评论数目
        """
        return await XiaoHongShuCommentSearch().search_comments(urls=urls, count=count)

    async def get_hot_topic_comments(self, keyword: str) -> XiaoHongShuHotTopicResponse:
        r"""
        搜索关键词，得到多篇热门笔记的热评
        :param keyword: 搜索关键字
        """
        return await XiaoHongShuHotTopic().get_hot_topic_comments(keyword=keyword)

    async def get_comments(self, url: str) -> XiaoHongShuCommentResponse:
        r"""
        通过小红书链接，获取笔记评论数据
        :param url: 笔记的URL地址
        """
        return await XiaoHongShuComment().get_comments(url=url)

    async def get_note_details(self, url: str) -> XiaoHongShuNoteDetailResponse:
        r"""
        通过小红书笔记链接，获取详细信息如标题、正文等
        :param url: 笔记的URL地址
        """
        return await XiaoHongShuNote().get_note_details(url=url)

    async def search_notes(self, question: str) -> XiaoHongShuSearchNotesResponse:
        r"""
        根据关键词搜索笔记，返回指定数量的笔记详情
        :param question: 搜索的关键词
        """
        return await XiaoHongShuNoteSearch().search_notes(question=question)

    async def search_popular_notes(self, keyword: str, count: int) -> XiaoHongShuVogueNoteSearchResponse:
        r"""
        根据搜索关键词获取小红书上的爆款笔记
        :param keyword: 搜索的关键词
        :param count: 要获取的笔记数量
        """
        return await XiaoHongShuVogueNoteSearch().search_vogue_notes(keyword=keyword, count=count)

    async def search_low_follower_popular_notes(self, keyword: str, count: int) -> XiaoHongShuPopularNotesResponse:
        r"""
        获取小红书上的低粉爆款笔记
        :param keyword: 搜索的关键词
        :param count: 要获取的笔记数量
        """
        return await XiaoHongShuPopularNotesWithLowFollowerSearch().search_low_follower_hits(keyword=keyword, count=count)

    async def search_account_notes(self, author_id: str, count: int) -> XiaoHongShuAccountNoteSearchResponse:
        r"""
        根据小红书账号ID查询该账号下最热门笔记
        :param author_id: 小红书账号ID
        :param count: 要获取的笔记数量
        """
        return await XiaoHongShuAccountNoteSearch().search_account_notes(author_id=author_id, count=count)

    async def get_hot_topics(self) -> XiaoHongShuHotTopicResponse:
        r"""
        获取小红书实时热点及相关热贴和评论
        """
        return await XiaoHongShuHotspots().get_hotspots()


class DouyinPlugin:
    r"""
    抖音类插件
    """

    async def get_comments(self, url: str) -> DouyinCommentsResponse:
        r"""
        通过抖音链接，获取相关评论
        :param url: 抖音视频的URL地址
        """
        return await DouyinComments().get_comments(url=url)

    async def analyze_video(self, url: str) -> DouyinVideoAnalysisResponse:
        r"""
        通过抖音链接，获取视频文案和相关截图
        :param url: 抖音视频的URL地址
        """
        return await DouyinVideoAnalysis().analyze_video(url=url)

    async def get_hot_topics(self, type: DouyinHotspotsType = DouyinHotspotsType.hot) -> DouYinHotTopicResponse:
        r"""
        获取抖音实时热搜榜
        :param type: 榜单类型（如“热榜”、“娱乐榜”等）
        """
        return await DouyinHotspots().get_hotspots(type=type)


class ZhihuPlugin:
    r"""
    知乎类插件
    """

    async def get_hot_topics(self) -> ZhiHuHotTopicResponse:
        r"""
        获取知乎实时热搜榜
        """
        return await ZhihuRealtimeHotspots().get_hotspots()


class BilibiliPlugin:
    r"""
    Bilibili类插件
    """

    async def get_hot_topics(self) -> BiliBiliHotTopicResponse:
        r"""
        获取bilibili实时热搜榜
        """
        return await BilibiliRealtimeHotspots().get_hotspots()


class ToutiaoPlugin:
    r"""
    今日头条类插件
    """

    async def get_hot_topics(self) -> ToutiaoTouTiaoHotTopicResponse:
        r"""
        获取今日头条实时热搜榜
        """
        return await ToutiaoHotspots().get_hotspots()


class WeiboPlugin:
    r"""
    微博类插件
    """

    async def get_hot_topics(self) -> WeiboHotspotsResponse:
        r"""
        获取微博实时热搜榜单
        """
        return await WeiboHotspots().fetch_hotspots()




from setuptools import setup, find_packages

setup(
    name="betteryeah",
    version="0.2.4",
    packages=find_packages(),
    description="this package is design by betteryeah.this client is package that to enhance user ability",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    author="ciqian",
    author_email="ciqian@bantouyan.com",
    install_requires=[
        # 依赖列表
    ],
    python_requires='>=3.10',  # 指定支持的最低Python版本
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
